"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.availableFonts = exports.fontWeightMapping = exports.lineHeightMapping = exports.fontSizeMapping = exports.fontMapping = exports.remFontSizeMapping = exports.remTextSansSizes = exports.remBodySizes = exports.remHeadlineSizes = exports.remTitlepieceSizes = exports.remFontSizes = exports.textSansSizes = exports.bodySizes = exports.headlineSizes = exports.titlepieceSizes = void 0;
const theme_1 = require("../theme");
const utils_1 = require("../utils");
const titlepieceSizes = {
    small: theme_1.fontSizes[8],
    medium: theme_1.fontSizes[9],
    large: theme_1.fontSizes[10],
};
exports.titlepieceSizes = titlepieceSizes;
const headlineSizes = {
    xxxsmall: theme_1.fontSizes[3],
    xxsmall: theme_1.fontSizes[4],
    xsmall: theme_1.fontSizes[5],
    small: theme_1.fontSizes[6],
    medium: theme_1.fontSizes[7],
    large: theme_1.fontSizes[8],
    xlarge: theme_1.fontSizes[9],
};
exports.headlineSizes = headlineSizes;
const bodySizes = {
    small: theme_1.fontSizes[2],
    medium: theme_1.fontSizes[3],
};
exports.bodySizes = bodySizes;
const textSansSizes = {
    xxsmall: theme_1.fontSizes[0],
    xsmall: theme_1.fontSizes[1],
    small: theme_1.fontSizes[2],
    medium: theme_1.fontSizes[3],
    large: theme_1.fontSizes[4],
    xlarge: theme_1.fontSizes[5],
    xxlarge: theme_1.fontSizes[6],
    xxxlarge: theme_1.fontSizes[7],
};
exports.textSansSizes = textSansSizes;
const fontSizeMapping = {
    titlepiece: titlepieceSizes,
    headline: headlineSizes,
    body: bodySizes,
    textSans: textSansSizes,
};
exports.fontSizeMapping = fontSizeMapping;
const remFontSizes = theme_1.fontSizes.map((fontSize) => utils_1.pxToRem(fontSize));
exports.remFontSizes = remFontSizes;
const remTitlepieceSizes = {
    small: remFontSizes[8],
    medium: remFontSizes[9],
    large: remFontSizes[10],
};
exports.remTitlepieceSizes = remTitlepieceSizes;
const remHeadlineSizes = {
    xxxsmall: remFontSizes[3],
    xxsmall: remFontSizes[4],
    xsmall: remFontSizes[5],
    small: remFontSizes[6],
    medium: remFontSizes[7],
    large: remFontSizes[8],
    xlarge: remFontSizes[9],
};
exports.remHeadlineSizes = remHeadlineSizes;
const remBodySizes = {
    small: remFontSizes[2],
    medium: remFontSizes[3],
};
exports.remBodySizes = remBodySizes;
const remTextSansSizes = {
    xxsmall: remFontSizes[0],
    xsmall: remFontSizes[1],
    small: remFontSizes[2],
    medium: remFontSizes[3],
    large: remFontSizes[4],
    xlarge: remFontSizes[5],
    xxlarge: remFontSizes[6],
    xxxlarge: remFontSizes[7],
};
exports.remTextSansSizes = remTextSansSizes;
const remFontSizeMapping = {
    titlepiece: remTitlepieceSizes,
    headline: remHeadlineSizes,
    body: remBodySizes,
    textSans: remTextSansSizes,
};
exports.remFontSizeMapping = remFontSizeMapping;
const fontMapping = {
    titlepiece: theme_1.fonts.titlepiece,
    headline: theme_1.fonts.headlineSerif,
    body: theme_1.fonts.bodySerif,
    textSans: theme_1.fonts.bodySans,
};
exports.fontMapping = fontMapping;
const lineHeightMapping = {
    tight: theme_1.lineHeights[0],
    regular: theme_1.lineHeights[1],
    loose: theme_1.lineHeights[2],
};
exports.lineHeightMapping = lineHeightMapping;
const fontWeightMapping = {
    light: theme_1.fontWeights[0],
    regular: theme_1.fontWeights[1],
    medium: theme_1.fontWeights[2],
    bold: theme_1.fontWeights[3],
};
exports.fontWeightMapping = fontWeightMapping;
const availableFonts = {
    titlepiece: {
        bold: {
            hasItalic: false,
        },
    },
    headline: {
        light: {
            hasItalic: true,
        },
        medium: {
            hasItalic: true,
        },
        bold: {
            hasItalic: false,
        },
    },
    body: {
        regular: {
            hasItalic: true,
        },
        bold: {
            hasItalic: true,
        },
    },
    textSans: {
        regular: {
            hasItalic: true,
        },
        bold: {
            hasItalic: false,
        },
    },
};
exports.availableFonts = availableFonts;
Object.freeze(titlepieceSizes);
Object.freeze(headlineSizes);
Object.freeze(bodySizes);
Object.freeze(textSansSizes);
Object.freeze(remTitlepieceSizes);
Object.freeze(remHeadlineSizes);
Object.freeze(remBodySizes);
Object.freeze(remTextSansSizes);
Object.freeze(fontMapping);
Object.freeze(fontSizeMapping);
Object.freeze(fontWeightMapping);
Object.freeze(lineHeightMapping);
Object.freeze(availableFonts);
//# sourceMappingURL=data.js.map